'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

// The theme file is based on the specification at https://system-ui.com/theme
//
// WARNING!
//
// This is an internal file to be consumed by the src-foundations package only
//
// It contains the lowest level primitives for the entire design system.
// Be very, *very* careful when changing the values in here, changes are likely
// to have a wide-ranging impact across all applications
//
// DANGEROUS CHANGES
//
// The following will almost certainly require further changes to src-foundations.
// They will likely also impact every application that consumes src-foundations
//
// - Updating a value
// - Removing a value
// - Inserting a value into an array
//
// SAFE CHANGES
//
// - Pushing a value onto the end of an array
// - Exporting a new object or array
var fontSizes = [12, 14, 15, 17, 20, 24, 28, 34, 42, 50, 70];
var fonts = {
  titlepiece: "GT Guardian Titlepiece, Georgia, serif",
  headlineSerif: "GH Guardian Headline, Guardian Egyptian Web, Georgia, serif",
  bodySerif: "GuardianTextEgyptian, Guardian Text Egyptian Web, Georgia, serif",
  bodySans: "GuardianTextSans, Guardian Text Sans Web, Helvetica Neue, Helvetica, Arial, Lucida Grande, sans-serif"
};
var lineHeights = [1.15, 1.35, 1.5];
var fontWeights = [300, 400, 500, 700]; // Arrays of colours should have pillar colors first

var rootPixelFontSize = 16;
var pxToRem = function pxToRem(px) {
  return px / rootPixelFontSize;
};

var titlepieceSizes = {
  small: fontSizes[8],
  //42px
  medium: fontSizes[9],
  //50px
  large: fontSizes[10] //70px

};
var headlineSizes = {
  xxxsmall: fontSizes[3],
  //17px
  xxsmall: fontSizes[4],
  //20px
  xsmall: fontSizes[5],
  //24px
  small: fontSizes[6],
  //28px
  medium: fontSizes[7],
  //34px
  large: fontSizes[8],
  //42px
  xlarge: fontSizes[9] //50px

};
var bodySizes = {
  small: fontSizes[2],
  //15px
  medium: fontSizes[3] //17px

};
var textSansSizes = {
  xxsmall: fontSizes[0],
  //12px
  xsmall: fontSizes[1],
  //14px
  small: fontSizes[2],
  //15px
  medium: fontSizes[3],
  //17px
  large: fontSizes[4],
  //20px
  xlarge: fontSizes[5],
  //24px
  xxlarge: fontSizes[6],
  //28px
  xxxlarge: fontSizes[7] //34px

};
var fontSizeMapping = {
  titlepiece: titlepieceSizes,
  headline: headlineSizes,
  body: bodySizes,
  textSans: textSansSizes
};
var remFontSizes = fontSizes.map(function (fontSize) {
  return pxToRem(fontSize);
});
var remTitlepieceSizes = {
  small: remFontSizes[8],
  //42px
  medium: remFontSizes[9],
  //50px
  large: remFontSizes[10] //70px

};
var remHeadlineSizes = {
  xxxsmall: remFontSizes[3],
  //17px
  xxsmall: remFontSizes[4],
  //20px
  xsmall: remFontSizes[5],
  //24px
  small: remFontSizes[6],
  //28px
  medium: remFontSizes[7],
  //34px
  large: remFontSizes[8],
  //42px
  xlarge: remFontSizes[9] //50px

};
var remBodySizes = {
  small: remFontSizes[2],
  //15px
  medium: remFontSizes[3] //17px

};
var remTextSansSizes = {
  xxsmall: remFontSizes[0],
  //12px
  xsmall: remFontSizes[1],
  //14px
  small: remFontSizes[2],
  //15px
  medium: remFontSizes[3],
  //17px
  large: remFontSizes[4],
  //20px
  xlarge: remFontSizes[5],
  //24px
  xxlarge: remFontSizes[6],
  //28px
  xxxlarge: remFontSizes[7] //34px

};
var remFontSizeMapping = {
  titlepiece: remTitlepieceSizes,
  headline: remHeadlineSizes,
  body: remBodySizes,
  textSans: remTextSansSizes
};
var fontMapping = {
  titlepiece: fonts.titlepiece,
  headline: fonts.headlineSerif,
  body: fonts.bodySerif,
  textSans: fonts.bodySans
};
var lineHeightMapping = {
  tight: lineHeights[0],
  regular: lineHeights[1],
  loose: lineHeights[2]
};
var fontWeightMapping = {
  light: fontWeights[0],
  regular: fontWeights[1],
  medium: fontWeights[2],
  bold: fontWeights[3]
};
var availableFonts = {
  titlepiece: {
    bold: {
      hasItalic: false
    }
  },
  headline: {
    light: {
      hasItalic: true
    },
    medium: {
      hasItalic: true
    },
    bold: {
      hasItalic: false
    }
  },
  body: {
    regular: {
      hasItalic: true
    },
    bold: {
      hasItalic: true
    }
  },
  textSans: {
    regular: {
      hasItalic: true
    },
    bold: {
      hasItalic: false
    }
  }
};
Object.freeze(titlepieceSizes);
Object.freeze(headlineSizes);
Object.freeze(bodySizes);
Object.freeze(textSansSizes);
Object.freeze(remTitlepieceSizes);
Object.freeze(remHeadlineSizes);
Object.freeze(remBodySizes);
Object.freeze(remTextSansSizes);
Object.freeze(fontMapping);
Object.freeze(fontSizeMapping);
Object.freeze(fontWeightMapping);
Object.freeze(lineHeightMapping);
Object.freeze(availableFonts);

function getFontStyle(font, fontStyle) {
  switch (fontStyle) {
    case "italic":
      return font && font.hasItalic ? "italic" : null;

    case "normal":
      return "normal";

    case null:
    default:
      return null;
  }
}

var fs = function fs(category) {
  return function (level, _ref) {
    var lineHeight = _ref.lineHeight,
        fontWeight = _ref.fontWeight,
        fontStyle = _ref.fontStyle,
        unit = _ref.unit;
    var fontFamilyValue = fontMapping[category];
    var fontSizeValue = unit === "px" ? fontSizeMapping[category][level] : "".concat(remFontSizeMapping[category][level], "rem");
    var lineHeightValue = unit === "px" ? // line-height is defined as a unitless value, so we multiply
    // by the element's font-size in px to get the px value
    "".concat(lineHeightMapping[lineHeight] * fontSizeMapping[category][level], "px") : lineHeightMapping[lineHeight]; // TODO: consider logging an error in development if a requested
    // font is unavailable

    var requestedFont = availableFonts[category][fontWeight];
    var fontWeightValue = requestedFont ? fontWeightMapping[fontWeight] : "";
    var fontStyleValue = getFontStyle(requestedFont, fontStyle);
    return Object.assign({
      fontFamily: fontFamilyValue,
      fontSize: fontSizeValue,
      lineHeight: lineHeightValue
    }, fontWeightValue ? {
      fontWeight: fontWeightValue
    } : {}, fontStyleValue ? {
      fontStyle: fontStyleValue
    } : {});
  };
};

var titlepieceDefaults = {
  lineHeight: "tight",
  fontWeight: "bold",
  fontStyle: null,
  unit: "rem"
};
var titlepieceFs = fs("titlepiece");
var titlepiece = {
  small: function small(options) {
    return titlepieceFs("small", Object.assign({}, titlepieceDefaults, options));
  },
  medium: function medium(options) {
    return titlepieceFs("medium", Object.assign({}, titlepieceDefaults, options));
  },
  large: function large(options) {
    return titlepieceFs("large", Object.assign({}, titlepieceDefaults, options));
  }
};
var headlineDefaults = {
  lineHeight: "tight",
  fontWeight: "medium",
  fontStyle: null,
  unit: "rem"
};
var headlineFs = fs("headline");
var headline = {
  xxxsmall: function xxxsmall(options) {
    return headlineFs("xxxsmall", Object.assign({}, headlineDefaults, options));
  },
  xxsmall: function xxsmall(options) {
    return headlineFs("xxsmall", Object.assign({}, headlineDefaults, options));
  },
  xsmall: function xsmall(options) {
    return headlineFs("xsmall", Object.assign({}, headlineDefaults, options));
  },
  small: function small(options) {
    return headlineFs("small", Object.assign({}, headlineDefaults, options));
  },
  medium: function medium(options) {
    return headlineFs("medium", Object.assign({}, headlineDefaults, options));
  },
  large: function large(options) {
    return headlineFs("large", Object.assign({}, headlineDefaults, options));
  },
  xlarge: function xlarge(options) {
    return headlineFs("xlarge", Object.assign({}, headlineDefaults, options));
  }
};
var bodyDefaults = {
  lineHeight: "loose",
  fontWeight: "regular",
  fontStyle: null,
  unit: "rem"
};
var bodyFs = fs("body");
var body = {
  small: function small(options) {
    return bodyFs("small", Object.assign({}, bodyDefaults, options));
  },
  medium: function medium(options) {
    return bodyFs("medium", Object.assign({}, bodyDefaults, options));
  }
};
var textSansDefaults = {
  lineHeight: "loose",
  fontWeight: "regular",
  fontStyle: null,
  unit: "rem"
};
var textSansFs = fs("textSans");
var textSans = {
  xxsmall: function xxsmall(options) {
    return textSansFs("xxsmall", Object.assign({}, textSansDefaults, options));
  },
  xsmall: function xsmall(options) {
    return textSansFs("xsmall", Object.assign({}, textSansDefaults, options));
  },
  small: function small(options) {
    return textSansFs("small", Object.assign({}, textSansDefaults, options));
  },
  medium: function medium(options) {
    return textSansFs("medium", Object.assign({}, textSansDefaults, options));
  },
  large: function large(options) {
    return textSansFs("large", Object.assign({}, textSansDefaults, options));
  },
  xlarge: function xlarge(options) {
    return textSansFs("xlarge", Object.assign({}, textSansDefaults, options));
  },
  xxlarge: function xxlarge(options) {
    return textSansFs("xxlarge", Object.assign({}, textSansDefaults, options));
  },
  xxxlarge: function xxxlarge(options) {
    return textSansFs("xxxlarge", Object.assign({}, textSansDefaults, options));
  }
};

exports.body = body;
exports.bodySizes = bodySizes;
exports.fontWeights = fontWeightMapping;
exports.fonts = fontMapping;
exports.headline = headline;
exports.headlineSizes = headlineSizes;
exports.lineHeights = lineHeightMapping;
exports.remBodySizes = remBodySizes;
exports.remHeadlineSizes = remHeadlineSizes;
exports.remTextSansSizes = remTextSansSizes;
exports.remTitlepieceSizes = remTitlepieceSizes;
exports.textSans = textSans;
exports.textSansSizes = textSansSizes;
exports.titlepiece = titlepiece;
exports.titlepieceSizes = titlepieceSizes;
