function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

var TAB_KEY_CODE = 9;
/**
 * Source: Blueprint https://blueprintjs.com/
 * https://github.com/palantir/blueprint/blob/06a186c90758bbdca604ed6d7bf639c3d05b1fa0/packages/core/src/common/interactionMode.ts
 * A nifty little class that maintains event handlers to add a class to the container element
 * when entering "mouse mode" (on a `mousedown` event) and remove it when entering "keyboard mode"
 * (on a `tab` key `keydown` event).
 * Requires @babel/plugin-proposal-class-properties
 */

var InteractionModeEngine = /*#__PURE__*/function () {
  // tslint:disable-next-line:no-constructor-vars
  function InteractionModeEngine(container, className) {
    var _this = this;

    _classCallCheck(this, InteractionModeEngine);

    this.container = container;
    this.className = className;

    _defineProperty(this, "isRunning", false);

    _defineProperty(this, "handleKeyDown", function (e) {
      if (e.which === TAB_KEY_CODE) {
        _this.reset();

        _this.container.addEventListener("mousedown", _this.handleMouseDown);
      }
    });

    _defineProperty(this, "handleMouseDown", function () {
      _this.reset();

      _this.container.classList.add(_this.className);

      _this.container.addEventListener("keydown", _this.handleKeyDown);
    });
  }
  /** Returns whether the engine is currently running. */


  _createClass(InteractionModeEngine, [{
    key: "isActive",
    value: function isActive() {
      return this.isRunning;
    }
    /** Enable behavior which applies the given className when in mouse mode. */

  }, {
    key: "start",
    value: function start() {
      this.container.addEventListener("mousedown", this.handleMouseDown);
      this.isRunning = true;
    }
    /** Disable interaction mode behavior and remove className from container. */

  }, {
    key: "stop",
    value: function stop() {
      this.reset();
      this.isRunning = false;
    }
  }, {
    key: "reset",
    value: function reset() {
      this.container.classList.remove(this.className);
      this.container.removeEventListener("keydown", this.handleKeyDown);
      this.container.removeEventListener("mousedown", this.handleMouseDown);
    }
  }]);

  return InteractionModeEngine;
}();
var FOCUS_DISABLED = "src-focus-disabled";

var _focusEngine;

var focusEngine = function focusEngine() {
  if (!_focusEngine) _focusEngine = new InteractionModeEngine(document.documentElement, FOCUS_DISABLED);
  return _focusEngine;
};

var FocusStyleManager = {
  alwaysShowFocus: function alwaysShowFocus() {
    return focusEngine().stop();
  },
  isActive: function isActive() {
    return focusEngine().isActive();
  },
  onlyShowFocusOnTabs: function onlyShowFocusOnTabs() {
    return focusEngine().start();
  }
};

var rootPixelFontSize = 16;
var pxToRem = function pxToRem(px) {
  return px / rootPixelFontSize;
};

// The theme file is based on the specification at https://system-ui.com/theme
// e.g. for sport:
// const [sport300, sport400, sport500, sport600, sport800] = colors.blue

var colors = {
  reds: ["#660505", //news-100
  "#8B0000", //news-200
  "#AB0613", //news-300
  "#C70000", //news-400, error-400
  "#FF5943", //news-500
  "#FF9081", //news-550, error-500
  "#FFBAC8", //news-600
  "#FFF4F2" //news-800
  ],
  oranges: ["#672005", //opinion-100
  "#8D2700", //opinion-200
  "#CB4700", //opinion-300
  "#E05E00", //opinion-400
  "#FF7F0F", //opinion-500
  "#F9B376", //opinion-600
  "#FEF9F5" //opinion-800
  ],
  blues: ["#003C60", //sport-100
  "#004E7C", //sport-200
  "#005689", //sport-300
  "#0084C6", //sport-400
  "#00B2FF", //sport-500
  "#90DCFF", //sport-600
  "#F1F8FC", //sport-800
  "#001536", //brand-100
  "#041F4A", //brand-300
  "#052962", //brand-400
  "#007ABC", //brand-500
  "#506991", //brand-600
  "#C1D8FC" //brand-800
  ],
  browns: ["#2B2625", //culture-50
  "#3E3323", //culture-100
  "#574835", //culture-200
  "#6B5840", //culture-300
  "#A1845C", //culture-400
  "#EACCA0", //culture-500
  "#E7D4B9", //culture-600
  "#EFE8DD", //culture-700
  "#FBF6EF" //culture-800
  ],
  pinks: ["#510043", //lifestyle-100
  "#650054", //lifestyle-200
  "#7D0068", //lifestyle-300
  "#BB3B80", //lifestyle-400
  "#FFABDB", //lifestyle-500
  "#FEC8D3", //lifestyle-600
  "#FEEEF7" //lifestyle-800
  ],
  yellows: ["#F3C100", //brandAlt-200
  "#FFD900", //brandAlt-300
  "#FFE500" //brandAlt-400
  ],
  greens: ["#185E36", //green-300
  "#22874D", //green-400, success-400
  "#58D08B", //green-500, success-500
  "#4B8878", //labs-200
  "#65A897", //labs-300
  "#69D1CA" //labs-400
  ],
  grays: ["#000000", //neutral-0
  "#121212", //neutral-7
  "#1A1A1A", //neutral-10
  "#333333", //neutral-20
  "#767676", //neutral-46
  "#999999", //neutral-60
  "#DCDCDC", //neutral-86
  "#EDEDED", //neutral-93
  "#F6F6F6", //neutral-97
  "#FFFFFF", //neutral-100
  "#222527", //specialReport-100
  "#303538", //specialReport-200
  "#3F464A", //specialReport-300
  "#595C5F", //specialReport-400
  "#9DA0A2", //specialReport-450
  "#ABC2C9", //specialReport-500
  "#E4E5E8", //specialReport-700
  "#EFF1F2" //specialReport-800
  ]
};

// Global colour names that correspond to https://www.theguardian.design/2a1e5182b/p/938810-colour/b/587ef3
var brand = {
  100: colors.blues[7],
  300: colors.blues[8],
  400: colors.blues[9],
  500: colors.blues[10],
  600: colors.blues[11],
  800: colors.blues[12]
};
var neutral = {
  0: colors.grays[0],
  7: colors.grays[1],
  10: colors.grays[2],
  20: colors.grays[3],
  46: colors.grays[4],
  60: colors.grays[5],
  86: colors.grays[6],
  93: colors.grays[7],
  97: colors.grays[8],
  100: colors.grays[9]
};
var error = {
  400: colors.reds[3],
  500: colors.reds[5]
};
var success = {
  400: colors.greens[1],
  500: colors.greens[2]
};
var news = {
  100: colors.reds[0],
  200: colors.reds[1],
  300: colors.reds[2],
  400: colors.reds[3],
  500: colors.reds[4],
  550: colors.reds[5],
  600: colors.reds[6],
  800: colors.reds[7]
};

var background = {
  primary: neutral[100],
  secondary: neutral[97],
  inverse: neutral[10],
  ctaPrimary: brand[400],
  ctaPrimaryHover: "#234B8A",
  ctaSecondary: brand[800],
  ctaSecondaryHover: "#ACC9F7",
  ctaTertiaryHover: "#E5E5E5",
  input: neutral[100],
  inputChecked: brand[500]
};

var text = {
  primary: neutral[7],
  supporting: neutral[46],
  success: success[400],
  error: error[400],
  ctaPrimary: neutral[100],
  ctaSecondary: brand[400],
  ctaTertiary: brand[400],
  anchorPrimary: brand[500],
  anchorSecondary: neutral[7],
  userInput: neutral[7],
  inputLabel: neutral[7],
  inputLabelSupporting: neutral[46],
  inputChecked: brand[400],
  //choice card only
  inputHover: brand[400],
  //choice card only
  groupLabel: neutral[7],
  groupLabelSupporting: neutral[46],
  newsInverse: news[550]
};

// Element specific resets
////////////////////////////
// TODO: bring element-specific resets into defaults. They can then be removed
// from individual components

var legend = "\n\tpadding: 0;\n";
var fieldset = "\n\tborder: 0;\n\tpadding: 0;\n\tmargin: 0;\n"; // remove styling of invalid input elements that gets applied in Firefox

var input = "\n\t&:invalid {\n\t\tbox-shadow: none;\n\t}\n"; ////////////////////////////
// Default resets
////////////////////////////
// TODO: currently including this is optional but one day will be required
// see https://github.com/orgs/guardian/teams/client-side-infra/discussions/17

var defaults = "\n\t*, *:before, *:after {\n        box-sizing: border-box;\n    }\n    html {\n        -moz-osx-font-smoothing: grayscale;\n        -webkit-font-smoothing: antialiased;\n    }\n    html, body {\n        text-rendering: optimizeLegibility;\n        font-feature-settings: 'kern';\n        font-kerning: normal; /* Safari 7+, Firefox 24+, Chrome 33(?)+, Opera 21 */\n        font-variant-ligatures: common-ligatures;\n    }\n    body {\n        background-color: ".concat(background.primary, ";\n        color: ").concat(text.primary, ";\n    }\n    em {\n        font-style: italic;\n    }\n");
var resets = {
  legend: legend,
  fieldset: fieldset,
  input: input,
  defaults: defaults
};

export { FocusStyleManager, pxToRem, resets, rootPixelFontSize };
